@@ -1,6 +1,6 @@
 /* ide-editor-utilities.h
  *
- * Copyright (C) 2017 Christian Hergert <chergert@redhat.com>
+ * Copyright 2017 Christian Hergert <chergert@redhat.com>
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,12 +18,15 @@
 
 #pragma once
 
+#include "ide-version-macros.h"
+
 #include "layout/ide-layout-pane.h"
 
 G_BEGIN_DECLS
 
 #define IDE_TYPE_EDITOR_UTILITIES (ide_editor_utilities_get_type())
 
+IDE_AVAILABLE_IN_ALL
 G_DECLARE_FINAL_TYPE (IdeEditorUtilities, ide_editor_utilities, IDE, EDITOR_UTILITIES, IdeLayoutPane)
 
 /* Use GtkContainer api to add your DzlDockWidget */
